@@ -36,7 +36,6 @@ namespace Gwenview
 {
 
 class AbstractImageOperation;
-class ImageView;
 
 struct CropToolPrivate;
 class GWENVIEWLIB_EXPORT CropTool : public AbstractRasterImageViewTool
@@ -44,25 +43,25 @@ class GWENVIEWLIB_EXPORT CropTool : public AbstractRasterImageViewTool
     Q_OBJECT
 public:
     CropTool(RasterImageView* parent);
-    ~CropTool();
+    ~CropTool() Q_DECL_OVERRIDE;
 
     void setCropRatio(double ratio);
 
     void setRect(const QRect&);
     QRect rect() const;
 
-    virtual void paint(QPainter*) Q_DECL_OVERRIDE;
+    void paint(QPainter*) Q_DECL_OVERRIDE;
 
-    virtual void mousePressEvent(QGraphicsSceneMouseEvent*) Q_DECL_OVERRIDE;
-    virtual void mouseMoveEvent(QGraphicsSceneMouseEvent*) Q_DECL_OVERRIDE;
-    virtual void mouseReleaseEvent(QGraphicsSceneMouseEvent*) Q_DECL_OVERRIDE;
-    virtual void hoverMoveEvent(QGraphicsSceneHoverEvent*) Q_DECL_OVERRIDE;
-    virtual void keyPressEvent(QKeyEvent*) Q_DECL_OVERRIDE;
+    void mousePressEvent(QGraphicsSceneMouseEvent*) Q_DECL_OVERRIDE;
+    void mouseMoveEvent(QGraphicsSceneMouseEvent*) Q_DECL_OVERRIDE;
+    void mouseReleaseEvent(QGraphicsSceneMouseEvent*) Q_DECL_OVERRIDE;
+    void hoverMoveEvent(QGraphicsSceneHoverEvent*) Q_DECL_OVERRIDE;
+    void keyPressEvent(QKeyEvent*) Q_DECL_OVERRIDE;
 
-    virtual void toolActivated() Q_DECL_OVERRIDE;
-    virtual void toolDeactivated() Q_DECL_OVERRIDE;
+    void toolActivated() Q_DECL_OVERRIDE;
+    void toolDeactivated() Q_DECL_OVERRIDE;
 
-    virtual QWidget* widget() const Q_DECL_OVERRIDE;
+    QWidget* widget() const Q_DECL_OVERRIDE;
 
 Q_SIGNALS:
     void rectUpdated(const QRect&);
