@@ -19,9 +19,10 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 */
 // Self
-#include "abstractrasterimageviewtool.moc"
+#include "abstractrasterimageviewtool.h"
 
 // Qt
+#include <QGraphicsSceneWheelEvent>
 
 // KDE
 
@@ -53,4 +54,9 @@ RasterImageView* AbstractRasterImageViewTool::imageView() const
     return d->mRasterImageView;
 }
 
+void AbstractRasterImageViewTool::wheelEvent(QGraphicsSceneWheelEvent* event)
+{
+    event->ignore();
+}
+
 } // namespace
