@@ -133,10 +133,12 @@ void RedEyeReductionTool::paint(QPainter* painter)
 
 void RedEyeReductionTool::mousePressEvent(QGraphicsSceneMouseEvent* event)
 {
-    event->accept();
-    if (event->buttons() != Qt::LeftButton) {
+    if (event->buttons() != Qt::LeftButton
+        || event->modifiers() & Qt::ControlModifier) {
+        event->ignore();
         return;
     }
+    event->accept();
     if (d->mStatus == NotSet) {
         d->mToolWidget->diameterSpinBox->setValue(d->mDiameter);
         d->mToolWidget->showMainPage();
